@@ -1,4 +1,4 @@
-coxDKpls2DR.formula <- function(Xplan,time,time2,event,type,origin,typeres="deviance", collapse, weighted, scaleX=TRUE, scaleY=TRUE, ncomp=min(7,ncol(Xplan)), methodpls="kernelpls", validation = "CV", plot=FALSE, allres=FALSE,dataXplan=NULL,subset,weights,model_frame=FALSE, kernel="rbfdot",hyperkernel,...) {
+coxDKpls2DR.formula <- function(Xplan,time,time2,event,type,origin,typeres="deviance", collapse, weighted, scaleX=TRUE, scaleY=TRUE, ncomp=min(7,ncol(Xplan)), methodpls="kernelpls", validation = "CV", plot=FALSE, allres=FALSE,dataXplan=NULL,subset,weights,model_frame=FALSE, kernel="rbfdot",hyperkernel,verbose=TRUE,...) {
 
 if (missing(dataXplan)) 
 dataXplan <- environment(Xplan)
